@@ -1,3 +1,4 @@
+# SPDX-License-Identifier: MIT
 
 def is_port_available(port: int) -> bool:
     """Checks whether a specified port is available to be attached to.
@@ -13,6 +14,6 @@ def is_port_available(port: int) -> bool:
     import socket
 
     with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
-        in_use = s.connect_ex(('localhost', port)) == 0
+        in_use = s.connect_ex(('localhost', int(port))) == 0
 
     return not in_use
